aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--scumm/scumm.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/scumm/scumm.cpp b/scumm/scumm.cpp
index 5bb1ea9a82..5be15abe72 100644
--- a/scumm/scumm.cpp
+++ b/scumm/scumm.cpp
@@ -1436,8 +1436,9 @@ int ScummEngine::scummLoop(int delta) {
VAR(VAR_TMR_1) += delta;
VAR(VAR_TMR_2) += delta;
VAR(VAR_TMR_3) += delta;
- if ((_gameId == GID_ZAK256 || _gameId == GID_INDY3) && (_features & GF_FMTOWNS)) {
- // FM Towns version of Indy3 and Zak set three extra timers
+ if ((_gameId == GID_ZAK256) || (_gameId == GID_INDY3 && (_features & GF_FMTOWNS || _features & GF_AMIGA))) {
+ // Amiga and FM Towns version of Indy3 set three extra timers
+ // FM Towns version of Zak set three extra timers
VAR(39) += delta;
VAR(40) += delta;
VAR(41) += delta;